@@ -13,16 +13,15 @@ Instructions::Instructions(QWidget *parent) :
     f.setBold(true);
     ui->labelHead->setFont(f);
     ui->labelHead->setText("Quick Guide to FlopSwap");
-    ui->labelMain->setText(tr( "<b>Fresh Swap</b><br>\
+    ui->labelMain->setText(tr("<b>There MUST be two uSD swaps,</b><br>\
+                               <b>and one device swap minimum.</b><br>\
+                               <b>Fresh Swap</b><br>\
                                Moves Swap to a fresh SD location<br>\
                                <b>Swap to Device</b><br>\
                                To allow back cover removal<br>\
-                               <b>Show Current</b><br>\
+                               <b>Check</b><br>\
                                Shows current swap location(s)<br>\
-                               <b>Check Usage</b><br>\
-                               Checks current swap usage<br>\
-                               <b>There MUST be two uSD swaps,</b><br>\
-                               <b>and one device swap minimum.</b>"));
+                               and checks current swap usage<br>"));
 
 }
 
