@@ -21,6 +21,7 @@
 
 MainWindow::MainWindow(QWidget *parent):
     QMainWindow(parent), ui(new Ui::MainWindow),
+      portrait(false),
       about(0),
       help(0),
       instructions(0),
@@ -37,14 +38,16 @@ MainWindow::MainWindow(QWidget *parent):
     //Set Button Text
     ui->pushButtonSwap->setText(tr("Fresh Swap"));
     ui->pushButtonEject->setText(tr("Swap to Device"));
-    ui->pushButtonGet->setText(tr("Show Current"));
-    ui->pushButtonSwapUsage->setText(tr("Check Status"));
+    ui->pushButtonEjectV->setText(tr("Swap to Device"));
+    ui->pushButtonGet->setText(tr("Check"));
+    //ui->pushButtonSwapUsage->setText(tr("Check Status"));
 
     // Set Button Icons
     ui->pushButtonSwap->setIcon(QPixmap("/opt/flopswap/icons/refresh_icon&32.png"));
     ui->pushButtonEject->setIcon(QPixmap("/opt/flopswap/icons/eject_icon&32.png"));
+    ui->pushButtonEjectV->setIcon(QPixmap("/opt/flopswap/icons/eject_icon&32.png"));
     ui->pushButtonGet->setIcon(QPixmap("/opt/flopswap/icons/info_icon&32.png"));
-    ui->pushButtonSwapUsage->setIcon(QPixmap("/opt/flopswap/icons/checkbox_checked_icon&32.png"));
+    //ui->pushButtonSwapUsage->setIcon(QPixmap("/opt/flopswap/icons/checkbox_checked_icon&32.png"));
 
     //Set Statusbar Font Size
     QFont f = ui->labelStat->font();
@@ -83,7 +86,7 @@ MainWindow::MainWindow(QWidget *parent):
     if (settingspage->startupCheck())
     {
         //If true click immediately after initialization
-        ui->pushButtonSwapUsage->click();
+        ui->pushButtonGet->click();
     }
 
     //GUI Blocking on Swap
@@ -166,7 +169,16 @@ void MainWindow::connectSignals()
     connect(new QShortcut(QKeySequence(Qt::Key_Q), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwap_clicked()));
     connect(new QShortcut(QKeySequence(Qt::Key_W), this), SIGNAL(activated()), this, SLOT(on_pushButtonEject_clicked()));
     connect(new QShortcut(QKeySequence(Qt::Key_A), this), SIGNAL(activated()), this, SLOT(on_pushButtonGet_clicked()));
-    connect(new QShortcut(QKeySequence(Qt::Key_S), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwapUsage_clicked()));
+    //connect(new QShortcut(QKeySequence(Qt::Key_S), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwapUsage_clicked()));
+}
+
+//Portrait switch
+void MainWindow::resizeEvent(QResizeEvent *event)
+{
+    portrait = event->size().width() <= 480;
+
+    ui->pushButtonEject->setVisible(!portrait);
+    ui->pushButtonEjectV->setVisible(portrait);
 }
 
 //Setup QSettings for Spin Box on First Run
@@ -254,13 +266,15 @@ void MainWindow::disableStatus()
  if ( QFileInfo("/tmp/flopswapint").exists() )
    {
         ui->pushButtonEject->setDisabled(true);
-        ui->pushButtonSwapUsage->setDisabled(true);
+        ui->pushButtonEjectV->setDisabled(true);
+        ui->pushButtonGet->setDisabled(true);
         ui->labelStat->setText("Safe to Remove Back Cover");
    }
  else
    {
         ui->pushButtonEject->setDisabled(false);
-        ui->pushButtonSwapUsage->setDisabled(false);
+        ui->pushButtonEjectV->setDisabled(false);
+        ui->pushButtonGet->setDisabled(false);
           if ( QFileInfo("/tmp/flopswapcur").exists() )
           {
               QFile file("/tmp/flopswapcur");
@@ -310,8 +324,9 @@ void MainWindow::disableButtons()
     this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
     ui->pushButtonSwap->setDisabled(true);
     ui->pushButtonEject->setDisabled(true);
+    ui->pushButtonEjectV->setDisabled(true);
     ui->pushButtonGet->setDisabled(true);
-    ui->pushButtonSwapUsage->setDisabled(true);
+    //ui->pushButtonSwapUsage->setDisabled(true);
 }
 
 //Use to enable Buttons on QProcess complete
@@ -320,8 +335,9 @@ void MainWindow::enableButtons()
     this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
     ui->pushButtonSwap->setDisabled(false);
     ui->pushButtonEject->setDisabled(false);
+    ui->pushButtonEjectV->setDisabled(false);
     ui->pushButtonGet->setDisabled(false);
-    ui->pushButtonSwapUsage->setDisabled(false);
+    //ui->pushButtonSwapUsage->setDisabled(false);
     disableStatus();
 }
 
@@ -338,16 +354,23 @@ void MainWindow::on_pushButtonEject_clicked()
     ejectseen();
 }
 
-void MainWindow::on_pushButtonGet_clicked()
+void MainWindow::on_pushButtonEjectV_clicked()
 {
-    m_process->start("sudo /opt/flopswap/script/catprocswap.sh");
+    ejectshow();
+    m_process->start("sudo /opt/flopswap/script/swapswitchejectsd.sh");
+    ejectseen();
 }
 
+void MainWindow::on_pushButtonGet_clicked()
+{
+    m_process->start("sudo /opt/flopswap/script/swapused.sh");
+}
+/*
 void MainWindow::on_pushButtonSwapUsage_clicked()
 {
     m_process->start("sudo /opt/flopswap/script/swapused.sh");
 }
-
+*/
 //Actions
 void MainWindow::on_actionAbout_triggered()
 {
