@@ -32,6 +32,9 @@ public:
 
     void showExpanded();
 
+protected:
+    void resizeEvent(QResizeEvent *event);
+
 private slots:
 
     // For Connecting Keyboard buttons
@@ -42,9 +45,11 @@ private slots:
 
     void on_pushButtonEject_clicked();
 
+    void on_pushButtonEjectV_clicked();
+
     void on_pushButtonGet_clicked();
 
-    void on_pushButtonSwapUsage_clicked();
+    //void on_pushButtonSwapUsage_clicked();
 
     void on_actionAbout_triggered();
 
@@ -74,6 +79,7 @@ private slots:
 
 private:
     Ui::MainWindow *ui;
+    bool portrait;
     About *about;
     Help *help;
     Instructions *instructions;
